@@ -2,40 +2,10 @@
 
 set -ex
 
-function docker_pull_retry() {
-    retry=0
-    maxRetries=5
-    retryAfterSeconds=3
-    until [ ${retry} -ge ${maxRetries} ]; do
-        docker pull $@ && break
-        retry=$((${retry} + 1))
-        echo "Retrying ${FUNCNAME} [${retry}/${maxRetries}] in ${retryAfterSeconds}(s)"
-        sleep ${retryAfterSeconds}
-    done
+cni_manifest="/tmp/cni.yaml"
 
-    if [ ${retry} -ge ${maxRetries} ]; then
-        echo "${FUNCNAME} Failed after ${maxRetries} attempts!"
-        exit 1
-    fi
-}
-
-kubeadmn_patches_path="/provision/kubeadm-patches"
-
-# Need to have the latest kernel
-dnf update -y kernel
-
-# Resize root partition
-dnf install -y cloud-utils-growpart
-if growpart /dev/vda 1; then
-    xfs_growfs -d /
-fi
-
-mkdir -p /provision
-
-cni_manifest="/provision/cni.yaml"
-cp /tmp/cni.yaml $cni_manifest
-
-cp /tmp/local-volume.yaml /provision/local-volume.yaml
+setenforce 0
+sed -i "s/^SELINUX=.*/SELINUX=permissive/" /etc/selinux/config
 
 # Disable swap
 swapoff -a
@@ -54,68 +24,41 @@ yum -y remove firewalld
 # Required for iscsi demo to work.
 yum -y install iscsi-initiator-utils
 
-# To prevent preflight issue realted to tc not found
-dnf install -y tc
-
-# Install docker required packages.
-dnf -y install yum-utils \
-    device-mapper-persistent-data \
-    lvm2
-
-# Add Docker repository.
-dnf config-manager --add-repo=https://download.docker.com/linux/centos/docker-ce.repo
-
-# Install package(s) that trigger the enablement of the container-tools yum module
-dnf -y install container-selinux
-
-# Disable the container-tools module, as it forces containerd.io to an ancient version,
-#   which in turn forces docker-ce to an older version, making it incompatible with docker-ce-cli...
-dnf -y module disable container-tools
-
-# Install Docker CE.
-dnf install -y docker-ce --nobest
-
-# Create /etc/docker directory.
-mkdir /etc/docker
-
-# Setup docker daemon
-cat << EOF > /etc/docker/daemon.json
-{
-  "insecure-registries" : ["registry:5000"],
-  "log-driver": "json-file",
-  "exec-opts": ["native.cgroupdriver=systemd"],
-  "ipv6": true,
-  "fixed-cidr-v6": "2001:db8:1::/64",
-  "selinux-enabled": true
-}
-EOF
-
-mkdir -p /etc/systemd/system/docker.service.d
-
-# Restart Docker
-systemctl daemon-reload
-systemctl restart docker
-
-#TODO: el8 repo
-# Add Kubernetes repository.
 cat <<EOF >/etc/yum.repos.d/kubernetes.repo
 [kubernetes]
 name=Kubernetes
-baseurl=https://packages.cloud.google.com/yum/repos/kubernetes-el7-x86_64
+baseurl=http://yum.kubernetes.io/repos/kubernetes-el7-x86_64
 enabled=1
 gpgcheck=1
-repo_gpgcheck=0
-gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
+repo_gpgcheck=1
+gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg
+       https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
 EOF
+yum install -y \
+  docker-1.13.1 \
+  python-docker-py-1.10.6 \
+  python3-pip
 
-# Install Kubernetes packages.
-dnf install --skip-broken --nobest --nogpgcheck --disableexcludes=kubernetes -y \
+pip3 install --default-timeout=100 docker-pycreds
+
+# Log to json files instead of journald
+sed -i 's/--log-driver=journald //g' /etc/sysconfig/docker
+echo '{ "insecure-registries" : ["registry:5000"] }' > /etc/docker/daemon.json
+
+# Enable the permanent logging
+# Required by the fluentd journald plugin
+# The default settings in recent distribution for systemd is set to auto,
+# when on auto journal is permament when /var/log/journal exists
+mkdir -p /var/log/journal
+
+# Omit pgp checks until https://github.com/kubernetes/kubeadm/issues/643 is resolved.
+yum install --nogpgcheck -y \
     kubeadm-${version} \
     kubelet-${version} \
     kubectl-${version} \
-    kubernetes-cni
+    kubernetes-cni-0.6.0
 
-# TODO use config file! this is deprecated
+    # TODO use config file! this is deprecated
 cat <<EOT >/etc/sysconfig/kubelet
 KUBELET_EXTRA_ARGS=--cgroup-driver=systemd --runtime-cgroups=/systemd/system.slice --kubelet-cgroups=/systemd/system.slice --feature-gates="BlockVolume=true,CSIBlockVolume=true,VolumeSnapshotDataSource=true"
 EOT
@@ -139,78 +82,11 @@ sysctl --system
 echo bridge >> /etc/modules
 echo br_netfilter >> /etc/modules
 
-# configure additional settings for cni plugin
-cat <<EOF >/etc/NetworkManager/conf.d/001-calico.conf
-[keyfile]
-unmanaged-devices=interface-name:cali*;interface-name:tunl*
-EOF
-
-# Use dhclient to have expected hostname behaviour
-cat <<EOF >/etc/NetworkManager/conf.d/002-dhclient.conf
-[main]
-dhcp=dhclient
-EOF
-
-sysctl -w net.netfilter.nf_conntrack_max=1000000
-echo "net.netfilter.nf_conntrack_max=1000000" >> /etc/sysctl.conf
-
-systemctl restart NetworkManager
-
-mkdir -p $kubeadmn_patches_path
-
-cat >$kubeadmn_patches_path/kustomization.yaml <<EOF
-patchesJson6902:
-- target:
-    version: v1
-    kind: Pod
-    name: kube-apiserver
-    namespace: kube-system
-  path: add-security-context.yaml
-- target:
-    version: v1
-    kind: Pod
-    name: kube-controller-manager
-    namespace: kube-system
-  path: add-security-context.yaml
-- target:
-    version: v1
-    kind: Pod
-    name: kube-scheduler
-    namespace: kube-system
-  path: add-security-context.yaml
-- target:
-    version: v1
-    kind: Pod
-    name: etcd
-    namespace: kube-system
-  path: add-security-context.yaml
-EOF
-
-cat >$kubeadmn_patches_path/add-security-context.yaml <<EOF
-- op: add
-  path: /spec/securityContext
-  value:
-    seLinuxOptions:
-      type: spc_t
-EOF
-
-cat >$kubeadmn_patches_path/add-security-context-deployment-patch.yaml <<EOF
-spec:
-  template:
-    spec:
-      securityContext:
-        seLinuxOptions:
-          type: spc_t
-EOF
-
-
 default_cidr="192.168.0.0/16"
 pod_cidr="10.244.0.0/16"
+kubeadm init --pod-network-cidr=$pod_cidr --kubernetes-version v${version} --token abcdef.1234567890123456
 
-kubeadm init --pod-network-cidr=$pod_cidr --kubernetes-version v${version} --token abcdef.1234567890123456 --experimental-kustomize $kubeadmn_patches_path/
-
-kubectl --kubeconfig=/etc/kubernetes/admin.conf patch deployment coredns -n kube-system -p "$(cat $kubeadmn_patches_path/add-security-context-deployment-patch.yaml)"
-sed -i -e "s?$default_cidr?$pod_cidr?g" $cni_manifest
+sed -i -e "s?$default_cidr?$pod_cidr?g" $cni_manifest 
 kubectl --kubeconfig=/etc/kubernetes/admin.conf create -f "$cni_manifest"
 
 # Wait at least for 7 pods
@@ -334,38 +210,17 @@ chmod -R 777 /var/local/kubevirt-storage/local-volume
 chcon -R unconfined_u:object_r:svirt_sandbox_file_t:s0 /mnt/local-storage/
 
 # Pre pull fluentd image used in logging
-docker_pull_retry fluent/fluentd:v1.2-debian
-docker_pull_retry fluent/fluentd-kubernetes-daemonset:v1.2-debian-syslog
+docker pull fluent/fluentd:v1.2-debian
+docker pull fluent/fluentd-kubernetes-daemonset:v1.2-debian-syslog
 
 # Pre pull images used in Ceph CSI
-docker_pull_retry quay.io/k8scsi/csi-attacher:v1.0.1
-docker_pull_retry quay.io/k8scsi/csi-provisioner:v1.0.1
-docker_pull_retry quay.io/k8scsi/csi-snapshotter:v1.0.1
-docker_pull_retry quay.io/cephcsi/rbdplugin:v1.0.0
-docker_pull_retry quay.io/k8scsi/csi-node-driver-registrar:v1.0.2
-
-# Pre pull cluster network addons operator images and store manifests
-# so we can use them at cluster-up
-cp -rf /tmp/cnao/ /opt/
-for i in $(grep -A 2 "IMAGE" /opt/cnao/operator.yaml | grep value | awk '{print $2}'); do docker_pull_retry $i; done
-
-# Pre pull local-volume-provisioner
-for i in $(grep -A 2 "IMAGE" /provision/local-volume.yaml | grep value | awk -F\" '{print $2}'); do docker_pull_retry $i; done
+docker pull quay.io/k8scsi/csi-attacher:v1.0.1
+docker pull quay.io/k8scsi/csi-provisioner:v1.0.1
+docker pull quay.io/k8scsi/csi-snapshotter:v1.0.1
+docker pull quay.io/cephcsi/rbdplugin:v1.0.0
+docker pull quay.io/k8scsi/csi-node-driver-registrar:v1.0.2
 
 # Create a properly labelled tmp directory for testing
 mkdir -p /provision/kubevirt.io/tests
 chcon -t container_file_t /provision/kubevirt.io/tests
 echo "tmpfs /provision/kubevirt.io/tests tmpfs rw,context=system_u:object_r:container_file_t:s0 0 1" >> /etc/fstab
-
-dnf install -y NetworkManager-config-server
-
-# Cleanup the existing NetworkManager profiles so the VM instances will come
-# up with the default profiles. (Base VM image includes non default settings)
-rm -f /etc/sysconfig/network-scripts/ifcfg-*
-nmcli connection add con-name eth0 ifname eth0 type ethernet
-
-# Temporarily disable dontaudit SELinux rules to see all the denials
-semodule -DB
-
-# Remove machine-id, allowing unique ID/s for its instances.
-rm -f /etc/machine-id ; touch /etc/machine-id
